import os
import json
import requests
from uuid import uuid4
from basicauth import encode


class Disbursement:
    def __init__(self):
        self.disbursements_primary_key = os.environ.get('DISBURSEMENT_PRIMARY_KEY')
        self.api_key_disbursements = os.environ.get('DISBURSEMENT_API_SECRET')
        self.disbursements_apiuser = os.environ.get('DISBURSEMENT_USER_ID')
        self.environment_mode = os.environ.get('MTN_ENVIRONMENT')
        self.callback_url = os.environ.get('CALLBACK_URL')
        self.base_url = os.environ.get('BASE_URL')
        

        if self.environment_mode == "sandbox":
            self.base_url = "https://sandbox.momodeveloper.mtn.com"

        # Generate Basic authorization key when in test mode
        if self.environment_mode == "sandbox":
            self.disbursements_apiuser = str(uuid4())

        # Create API user
        self.url = f"{self.base_url}/v1_0/apiuser"
        payload = json.dumps({
            "providerCallbackHost": os.environ.get('')
        })
        self.headers = {
            'X-Reference-Id': self.disbursements_apiuser,
            'Content-Type': 'application/json',
            'Ocp-Apim-Subscription-Key': self.disbursements_primary_key
        }
        response = requests.post(self.url, headers=self.headers, data=payload)

        # Auto-generate when in test mode
        if self.environment_mode == "sandbox":
            self.api_key_disbursements = str(response["apiKey"])

        # Create basic key for disbursements
        self.username, self.password = self.disbursements_apiuser, self.api_key_disbursements
        self.basic_authorisation_disbursements = str(encode(self.username, self.password))

    def authToken(self):
        url = f"{self.base_url}/disbursement/token/"
        payload = {}
        headers = {
            'Ocp-Apim-Subscription-Key': self.disbursements_primary_key,
            'Authorization': self.basic_authorisation_disbursements
        }
        response = requests.post(url, headers=headers, data=payload).json()
        return response

    def getBalance(self):
        url = f"{self.base_url}/disbursement/v1_0/account/balance"
        payload = {}
        headers = {
            'Ocp-Apim-Subscription-Key': self.disbursements_subkey,
            'Authorization':  "Bearer " + str(self.authToken()["access_token"]),
            'X-Target-Environment': self.environment_mode,
        }
        response = requests.request("GET", url, headers=headers, data=payload)
        json_respon = response.json()
        return json_respon

    def transfer(self, amount, phone_number, external_id,payermessage='',payermessageNone=''):
        url = f"{self.base_url}/disbursement/v1_0/transfer"
        payload = json.dumps({
            "amount": str(amount),
            "currency": os.environ.get('CURRENCY'),
            "externalId": str(external_id),
            "payee": {
                "partyIdType": "MSISDN",
                "partyId": phone_number
            },
            "payerMessage": payermessage,
            "payeeNote": payermessageNone
        })
        
        headers = {
            'X-Reference-Id': str(uuid4()),
            'X-Target-Environment': self.environment_mode,
            'X-Callback-Url': self.callback_url,
            'Ocp-Apim-Subscription-Key': self.subscription_key,
            'Content-Type': 'application/json',
            'Authorization':  "Bearer " + str(self.authToken()["access_token"])
            }
        proxies = {
            "http": os.environ.get('QUOTAGUARDSTATIC_URL'),
            "https": os.environ.get('QUOTAGUARDSTATIC_URL')
            }
        response = requests.post(url, headers=headers, json=payload, proxies=proxies)

        if response.status_code == 200:
            return response.json()
        else:
            raise Exception(f"Failed to fetch data from API. Status code: {response.status_code}, Error: {response.text}")
    

    def getTransactionStatus(self,txn_ref):

        url = f"{self.base_url}/disbursement/v1_0/transfer/{txn_ref}"

        payload = {}

        headers = {
            'X-Reference-Id': str(uuid4()),
            'X-Target-Environment': self.environment_mode,
            'Ocp-Apim-Subscription-Key': self.disbursements_primary_key,
            'Content-Type': 'application/json',
            'Authorization':  "Bearer " + str(self.authToken()["access_token"])
        }

        proxies = {
            "http": os.environ.get('QUOTAGUARDSTATIC_URL'),
            "https": os.environ.get('QUOTAGUARDSTATIC_URL')
            }

        response = requests.request("GET", url, headers=headers, data=payload, proxies=proxies)
        returneddata = response.json()

        res = {
            "response": response.status_code,
            "ref": txn_ref,
            "data": returneddata
        }
        return res



import os
from uuid import uuid4
import requests
import json
from uuid import uuid4
from basicauth import encode


class Collection:
    def __init__(self):
        self.collections_primary_key = os.environ.get('COLLECTION_PRIMARY_KEY')
        self.api_key_collections = os.environ.get('COLLECTION_API_SECRET')
        self.collections_apiuser = os.environ.get('COLLECTION_USER_ID')
        self.environment_mode = os.environ.get('MTN_ENVIRONMENT')
        self.callback_url = os.environ.get('CALLBACK_URL')
        self.base_url = os.environ.get('BASE_URL')
        
        if self.environment_mode == "sandbox":
            self.base_url = "https://sandbox.momodeveloper.mtn.com"

        # Generate Basic authorization key when in test mode
        if self.environment_mode == "sandbox":
            self.collections_apiuser = str(uuid4())

        # Create API user
        self.url = f"{self.base_url}/v1_0/apiuser"
        payload = json.dumps({
            "providerCallbackHost": os.environ.get('')
        })
        self.headers = {
            'X-Reference-Id': self.collections_apiuser,
            'Content-Type': 'application/json',
            'Ocp-Apim-Subscription-Key': self.collections_primary_key
        }
        response = requests.post(self.url, headers=self.headers, data=payload)

        # Auto-generate when in test mode
        if self.environment_mode == "sandbox":
            self.api_key_collections = str(response["apiKey"])

        # Create basic key for Collections
        self.username, self.password = self.collections_apiuser, self.api_key_collections
        self.basic_authorisation_collections = str(encode(self.username, self.password))

    def authToken(self):
        url = f"{self.base_url}/collection/token/"
        payload = {}
        headers = {
            'Ocp-Apim-Subscription-Key': self.collections_primary_key,
            'Authorization': self.basic_authorisation_collections
        }
        response = requests.post(url, headers=headers, data=payload).json()
        return response

    def requestToPay(self, amount, phone_number, external_id,payernote="SPARCO", payermessage="SPARCOPAY"):
        uuidgen = str(uuid4())
        url = f"{self.base_url}/collection/v1_0/requesttopay"
        payload = json.dumps({
            "amount": amount,
            "currency": os.environ.get('CURRENCY'),
            "externalId": external_id,
            "payer": {
                "partyIdType": "MSISDN",
                "partyId": phone_number
            },
            "payerMessage": payermessage,
            "payeeNote": payernote
        })
        headers = {
            'X-Reference-Id': uuidgen,
            'X-Target-Environment': self.environment_mode,
            'X-Callback-Url': self.callback_url,
            'Ocp-Apim-Subscription-Key': self.collections_primary_key,
            'Content-Type': 'application/json',
            'Authorization': "Bearer " + str(self.authToken()["access_token"])
        }
        response = requests.post(url, headers=headers, data=payload)

        context = {"status_code": response.status_code,"ref": uuidgen}
        return context

    def getTransactionStatus(self, txn):
        url = f"{self.base_url}/collection/v1_0/requesttopay/{txn}"
        payload = {}
        headers = {
            'Ocp-Apim-Subscription-Key': self.collections_primary_key,
        'Authorization': f"Bearer {self.authToken()['access_token']}",
            'X-Target-Environment': self.environment_mode,
        }
        response = requests.request("GET", url, headers=headers, data=payload)
        json_respon = response.json()
        return json_respon

    # Check momo collections balance
    def getBalance(self):
        url = f"{self.base_url}/collection/v1_0/account/balance"
        payload = {}
        headers = {
            'Ocp-Apim-Subscription-Key': self.collections_primary_key,
            'Authorization':  f"Bearer {self.authToken()['access_token']}",
            'X-Target-Environment': self.environment_mode,
        }
        response = requests.request("GET", url, headers=headers, data=payload)
        json_respon = response.json()
        return json_respon



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
from __future__ import absolute_import
from __future__ import print_function

from setuptools import setup, find_packages

with open("README.md", "r", encoding = "utf-8") as fh:
    long_description = fh.read()

setup(
    name='mtnmomoapi',
    version='0.0.6',
    license='MIT license',
    author = "Mathews Musukuma",
    author_email = "sikaili99@gmail.com",
    description = "An easy to use Python wrapper for the MTN MoMo API.",
    long_description = long_description,
    long_description_content_type = "text/markdown",
    url = "https://github.com/sikaili99/mtnmomoapi",
    project_urls = {
        "Bug Tracker": "https://github.com/sikaili99/mtnmomoapi/issues",
        "repository" : "https://github.com/sikaili99/mtnmomoapi"
    },
    classifiers = [
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    keywords=[
        'MoMo API', 'MoMo API Python Wrapper', 'MoMo API Python','MTN Zambia MoMO API Python', 'MTN Mobile Money API Python'
    ],
    package_dir = {"": "src"},
    packages = find_packages(where="src"),
    python_requires = ">=3.6"
)
